pub fn cli_main() -> ExitCodeExpand description
Full CLI entry point for cargo install aprender.
This function encapsulates the complete apr binary logic so that
the aprender facade crate can produce the same binary via
cargo install aprender (in addition to cargo install apr-cli).