pub fn read_stdin_to_tempfile() -> Result<TempModelFile, CliError>Expand description
Read all of stdin into a temporary file.
Returns a TempModelFile whose path can be passed to any function
expecting a file path (mmap, fs::read, etc.).
pub fn read_stdin_to_tempfile() -> Result<TempModelFile, CliError>Read all of stdin into a temporary file.
Returns a TempModelFile whose path can be passed to any function
expecting a file path (mmap, fs::read, etc.).