pub fn scope(level: Level, json: bool) -> VerbosityScopeExpand description
Override the level for the current thread until the guard drops.
pub fn scope(level: Level, json: bool) -> VerbosityScopeOverride the level for the current thread until the guard drops.